==> flutter_widgets-0.1.2.tar.gz: lib/src/visibility_detector/src/visibility_detector_controller.dart <==
// Copyright 2018 the Dart project authors.
//
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file or at
// https://developers.google.com/open-source/licenses/bsd

import 'package:flutter/foundation.dart';

import 'visibility_detector_layer.dart';

/// A [VisibilityDetectorController] is a singleton object that can perform
/// actions and change configuration for all [VisibilityDetector] widgets.
class VisibilityDetectorController {
  static final _instance = VisibilityDetectorController();
  static VisibilityDetectorController get instance => _instance;

  /// The minimum amount of time to wait between firing batches of visibility
  /// callbacks.
  ///
  /// If set to [Duration.zero], callbacks instead will fire at the end of every
  /// frame.  This is useful for automated tests.
  ///
  /// Changing [updateInterval] will not affect any pending callbacks.  Clients
  /// should call [notifyNow] explicitly to flush them if desired.
  Duration updateInterval = Duration(milliseconds: 500);

  /// Forces firing all pending visibility callbacks immmediately.
  ///
  /// This might be desirable just prior to tearing down the widget tree (such
  /// as when switching views or when exiting the application).
  void notifyNow() {
    VisibilityDetectorLayer.notifyNow();
  }

  /// Forgets any pending visibility callbacks for the `VisibilityDetector` with
  /// the given [key].
  ///
  /// Note if widget gets attached/detached the callback will be rescheduled.
  ///
  /// This method can be used to cancel timers, after the detector has been
  /// detached to avoid pending timers.
  void forget(Key key) {
    VisibilityDetectorLayer.forget(key);
  }
}

==> flutter_widgets-0.1.3.tar.gz: lib/src/visibility_detector/src/visibility_detector_controller.dart <==
// Copyright 2018 the Dart project authors.
//
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file or at
// https://developers.google.com/open-source/licenses/bsd

import 'package:flutter/foundation.dart';

import 'visibility_detector_layer.dart';

/// A [VisibilityDetectorController] is a singleton object that can perform
/// actions and change configuration for all [VisibilityDetector] widgets.
class VisibilityDetectorController {
  static final _instance = VisibilityDetectorController();
  static VisibilityDetectorController get instance => _instance;

  /// The minimum amount of time to wait between firing batches of visibility
  /// callbacks.
  ///
  /// If set to [Duration.zero], callbacks instead will fire at the end of every
  /// frame.  This is useful for automated tests.
  ///
  /// Changing [updateInterval] will not affect any pending callbacks.  Clients
  /// should call [notifyNow] explicitly to flush them if desired.
  Duration updateInterval = const Duration(milliseconds: 500);

  /// Forces firing all pending visibility callbacks immmediately.
  ///
  /// This might be desirable just prior to tearing down the widget tree (such
  /// as when switching views or when exiting the application).
  void notifyNow() {
    VisibilityDetectorLayer.notifyNow();
  }

  /// Forgets any pending visibility callbacks for the `VisibilityDetector` with
  /// the given [key].
  ///
  /// Note if widget gets attached/detached the callback will be rescheduled.
  ///
  /// This method can be used to cancel timers, after the detector has been
  /// detached to avoid pending timers.
  void forget(Key key) {
    VisibilityDetectorLayer.forget(key);
  }
}
